@@ -25,13 +25,23 @@ import os
 import socket
 import time
 import threading
+
+# TODO: switch as much of py3compat.py to 'six' as possible, then use six.wraps
 from functools import wraps
 
 from paramiko import util
-from paramiko.common import cMSG_CHANNEL_REQUEST, cMSG_CHANNEL_WINDOW_ADJUST, \
-    cMSG_CHANNEL_DATA, cMSG_CHANNEL_EXTENDED_DATA, DEBUG, ERROR, \
-    cMSG_CHANNEL_SUCCESS, cMSG_CHANNEL_FAILURE, cMSG_CHANNEL_EOF, \
-    cMSG_CHANNEL_CLOSE
+from paramiko.common import (
+    cMSG_CHANNEL_REQUEST,
+    cMSG_CHANNEL_WINDOW_ADJUST,
+    cMSG_CHANNEL_DATA,
+    cMSG_CHANNEL_EXTENDED_DATA,
+    DEBUG,
+    ERROR,
+    cMSG_CHANNEL_SUCCESS,
+    cMSG_CHANNEL_FAILURE,
+    cMSG_CHANNEL_EOF,
+    cMSG_CHANNEL_CLOSE,
+)
 from paramiko.message import Message
 from paramiko.py3compat import bytes_types
 from paramiko.ssh_exception import SSHException
@@ -45,9 +55,11 @@ def open_only(func):
     """
     Decorator for `.Channel` methods which performs an openness check.
 
-    :raises SSHException:
-        If the wrapped method is called on an unopened `.Channel`.
+    :raises:
+        `.SSHException` -- If the wrapped method is called on an unopened
+        `.Channel`.
     """
+
     @wraps(func)
     def _check(self, *args, **kwds):
         if (
@@ -56,12 +68,13 @@ def open_only(func):
             or self.eof_sent
             or not self.active
         ):
-            raise SSHException('Channel is not open')
+            raise SSHException("Channel is not open")
         return func(self, *args, **kwds)
+
     return _check
 
 
-class Channel (ClosingContextManager):
+class Channel(ClosingContextManager):
     """
     A secure tunnel across an SSH `.Transport`.  A Channel is meant to behave
     like a socket, and has an API that should be indistinguishable from the
@@ -74,7 +87,7 @@ class Channel (ClosingContextManager):
     flow-controlled independently.)  Similarly, if the server isn't reading
     data you send, calls to `send` may block, unless you set a timeout.  This
     is exactly like a normal network socket, so it shouldn't be too surprising.
-    
+
     Instances of this class may be used as context managers.
     """
 
@@ -88,15 +101,20 @@ class Channel (ClosingContextManager):
         :param int chanid:
             the ID of this channel, as passed by an existing `.Transport`.
         """
+        #: Channel ID
         self.chanid = chanid
+        #: Remote channel ID
         self.remote_chanid = 0
+        #: `.Transport` managing this channel
         self.transport = None
+        #: Whether the connection is presently active
         self.active = False
         self.eof_received = 0
         self.eof_sent = 0
         self.in_buffer = BufferedPipe()
         self.in_stderr_buffer = BufferedPipe()
         self.timeout = None
+        #: Whether the connection has been closed
         self.closed = False
         self.ultra_debug = False
         self.lock = threading.Lock()
@@ -109,7 +127,7 @@ class Channel (ClosingContextManager):
         self.in_window_sofar = 0
         self.status_event = threading.Event()
         self._name = str(chanid)
-        self.logger = util.get_logger('paramiko.transport')
+        self.logger = util.get_logger("paramiko.transport")
         self._pipe = None
         self.event = threading.Event()
         self.event_ready = False
@@ -127,44 +145,52 @@ class Channel (ClosingContextManager):
         """
         Return a string representation of this object, for debugging.
         """
-        out = '<paramiko.Channel %d' % self.chanid
+        out = "<paramiko.Channel {}".format(self.chanid)
         if self.closed:
-            out += ' (closed)'
+            out += " (closed)"
         elif self.active:
             if self.eof_received:
-                out += ' (EOF received)'
+                out += " (EOF received)"
             if self.eof_sent:
-                out += ' (EOF sent)'
-            out += ' (open) window=%d' % self.out_window_size
+                out += " (EOF sent)"
+            out += " (open) window={}".format(self.out_window_size)
             if len(self.in_buffer) > 0:
-                out += ' in-buffer=%d' % (len(self.in_buffer),)
-        out += ' -> ' + repr(self.transport)
-        out += '>'
+                out += " in-buffer={}".format(len(self.in_buffer))
+        out += " -> " + repr(self.transport)
+        out += ">"
         return out
 
     @open_only
-    def get_pty(self, term='vt100', width=80, height=24, width_pixels=0,
-                height_pixels=0):
+    def get_pty(
+        self,
+        term="vt100",
+        width=80,
+        height=24,
+        width_pixels=0,
+        height_pixels=0,
+    ):
         """
         Request a pseudo-terminal from the server.  This is usually used right
         after creating a client channel, to ask the server to provide some
         basic terminal semantics for a shell invoked with `invoke_shell`.
         It isn't necessary (or desirable) to call this method if you're going
-        to exectue a single command with `exec_command`.
+        to execute a single command with `exec_command`.
 
-        :param str term: the terminal type to emulate (for example, ``'vt100'``)
+        :param str term: the terminal type to emulate
+            (for example, ``'vt100'``)
         :param int width: width (in characters) of the terminal screen
         :param int height: height (in characters) of the terminal screen
         :param int width_pixels: width (in pixels) of the terminal screen
         :param int height_pixels: height (in pixels) of the terminal screen
 
-        :raises SSHException:
-            if the request was rejected or the channel was closed
+        :raises:
+            `.SSHException` -- if the request was rejected or the channel was
+            closed
         """
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('pty-req')
+        m.add_string("pty-req")
         m.add_boolean(True)
         m.add_string(term)
         m.add_int(width)
@@ -190,13 +216,14 @@ class Channel (ClosingContextManager):
         When the shell exits, the channel will be closed and can't be reused.
         You must open a new channel if you wish to open another shell.
 
-        :raises SSHException: if the request was rejected or the channel was
+        :raises:
+            `.SSHException` -- if the request was rejected or the channel was
             closed
         """
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('shell')
+        m.add_string("shell")
         m.add_boolean(True)
         self._event_pending()
         self.transport._send_user_message(m)
@@ -215,13 +242,14 @@ class Channel (ClosingContextManager):
 
         :param str command: a shell command to execute.
 
-        :raises SSHException: if the request was rejected or the channel was
+        :raises:
+            `.SSHException` -- if the request was rejected or the channel was
             closed
         """
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('exec')
+        m.add_string("exec")
         m.add_boolean(True)
         m.add_string(command)
         self._event_pending()
@@ -240,13 +268,14 @@ class Channel (ClosingContextManager):
 
         :param str subsystem: name of the subsystem being requested.
 
-        :raises SSHException:
-            if the request was rejected or the channel was closed
+        :raises:
+            `.SSHException` -- if the request was rejected or the channel was
+            closed
         """
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('subsystem')
+        m.add_string("subsystem")
         m.add_boolean(True)
         m.add_string(subsystem)
         self._event_pending()
@@ -264,13 +293,14 @@ class Channel (ClosingContextManager):
         :param int width_pixels: new width (in pixels) of the terminal screen
         :param int height_pixels: new height (in pixels) of the terminal screen
 
-        :raises SSHException:
-            if the request was rejected or the channel was closed
+        :raises:
+            `.SSHException` -- if the request was rejected or the channel was
+            closed
         """
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('window-change')
+        m.add_string("window-change")
         m.add_boolean(False)
         m.add_int(width)
         m.add_int(height)
@@ -278,6 +308,59 @@ class Channel (ClosingContextManager):
         m.add_int(height_pixels)
         self.transport._send_user_message(m)
 
+    @open_only
+    def update_environment(self, environment):
+        """
+        Updates this channel's remote shell environment.
+
+        .. note::
+            This operation is additive - i.e. the current environment is not
+            reset before the given environment variables are set.
+
+        .. warning::
+            Servers may silently reject some environment variables; see the
+            warning in `set_environment_variable` for details.
+
+        :param dict environment:
+            a dictionary containing the name and respective values to set
+        :raises:
+            `.SSHException` -- if any of the environment variables was rejected
+            by the server or the channel was closed
+        """
+        for name, value in environment.items():
+            try:
+                self.set_environment_variable(name, value)
+            except SSHException as e:
+                err = 'Failed to set environment variable "{}".'
+                raise SSHException(err.format(name), e)
+
+    @open_only
+    def set_environment_variable(self, name, value):
+        """
+        Set the value of an environment variable.
+
+        .. warning::
+            The server may reject this request depending on its ``AcceptEnv``
+            setting; such rejections will fail silently (which is common client
+            practice for this particular request type). Make sure you
+            understand your server's configuration before using!
+
+        :param str name: name of the environment variable
+        :param str value: value of the environment variable
+
+        :raises:
+            `.SSHException` -- if the request was rejected or the channel was
+            closed
+        """
+        m = Message()
+        m.add_byte(cMSG_CHANNEL_REQUEST)
+        m.add_int(self.remote_chanid)
+        m.add_string("env")
+        m.add_boolean(False)
+        m.add_string(name)
+        m.add_string(value)
+        self.transport._send_user_message(m)
+
     def exit_status_ready(self):
         """
         Return true if the remote process has exited and returned an exit
@@ -286,7 +369,8 @@ class Channel (ClosingContextManager):
         return an exit status in some cases (like bad servers).
 
         :return:
-            ``True`` if `recv_exit_status` will return immediately, else ``False``.
+            ``True`` if `recv_exit_status` will return immediately, else
+            ``False``.
 
         .. versionadded:: 1.7.3
         """
@@ -300,6 +384,17 @@ class Channel (ClosingContextManager):
         it does, or until the channel is closed.  If no exit status is
         provided by the server, -1 is returned.
 
+        .. warning::
+            In some situations, receiving remote output larger than the current
+            `.Transport` or session's ``window_size`` (e.g. that set by the
+            ``default_window_size`` kwarg for `.Transport.__init__`) will cause
+            `.recv_exit_status` to hang indefinitely if it is called prior to a
+            sufficiently large `.Channel.recv` (or if there are no threads
+            calling `.Channel.recv` in the background).
+
+            In these cases, ensuring that `.recv_exit_status` is called *after*
+            `.Channel.recv` (or, again, using threads) can avoid the hang.
+
         :return: the exit code (as an `int`) of the process on the server.
 
         .. versionadded:: 1.2
@@ -324,20 +419,26 @@ class Channel (ClosingContextManager):
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('exit-status')
+        m.add_string("exit-status")
         m.add_boolean(False)
         m.add_int(status)
         self.transport._send_user_message(m)
 
     @open_only
-    def request_x11(self, screen_number=0, auth_protocol=None, auth_cookie=None,
-                    single_connection=False, handler=None):
+    def request_x11(
+        self,
+        screen_number=0,
+        auth_protocol=None,
+        auth_cookie=None,
+        single_connection=False,
+        handler=None,
+    ):
         """
         Request an x11 session on this channel.  If the server allows it,
         further x11 requests can be made from the server to the client,
         when an x11 application is run in a shell session.
 
-        From RFC4254::
+        From :rfc:`4254`::
 
             It is RECOMMENDED that the 'x11 authentication cookie' that is
             sent be a fake, random cookie, and that the cookie be checked and
@@ -347,7 +448,7 @@ class Channel (ClosingContextManager):
         generated, used, and returned.  You will need to use this value to
         verify incoming x11 requests and replace them with the actual local
         x11 cookie (which requires some knowledge of the x11 protocol).
-        
+
         If a handler is passed in, the handler is called from another thread
         whenever a new x11 connection arrives.  The default handler queues up
         incoming x11 connections, which may be retrieved using
@@ -366,19 +467,19 @@ class Channel (ClosingContextManager):
             if True, only a single x11 connection will be forwarded (by
             default, any number of x11 connections can arrive over this
             session)
-        :param function handler:
-            an optional handler to use for incoming X11 connections
+        :param handler:
+            an optional callable handler to use for incoming X11 connections
         :return: the auth_cookie used
         """
         if auth_protocol is None:
-            auth_protocol = 'MIT-MAGIC-COOKIE-1'
+            auth_protocol = "MIT-MAGIC-COOKIE-1"
         if auth_cookie is None:
             auth_cookie = binascii.hexlify(os.urandom(16))
 
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('x11-req')
+        m.add_string("x11-req")
         m.add_boolean(True)
         m.add_boolean(single_connection)
         m.add_string(auth_protocol)
@@ -396,17 +497,19 @@ class Channel (ClosingContextManager):
         Request for a forward SSH Agent on this channel.
         This is only valid for an ssh-agent from OpenSSH !!!
 
-        :param function handler:
-            a required handler to use for incoming SSH Agent connections
+        :param handler:
+            a required callable handler to use for incoming SSH Agent
+            connections
 
-        :return: True if we are ok, else False (at that time we always return ok)
+        :return: True if we are ok, else False
+            (at that time we always return ok)
 
         :raises: SSHException in case of channel problem.
         """
         m = Message()
         m.add_byte(cMSG_CHANNEL_REQUEST)
         m.add_int(self.remote_chanid)
-        m.add_string('auth-agent-req@openssh.com')
+        m.add_string("auth-agent-req@openssh.com")
         m.add_boolean(False)
         self.transport._send_user_message(m)
         self.transport._set_forward_agent_handler(handler)
@@ -480,16 +583,16 @@ class Channel (ClosingContextManager):
             self._feed(data)
         return old
 
-    ###  socket API
+    # ...socket API...
 
     def settimeout(self, timeout):
         """
         Set a timeout on blocking read/write operations.  The ``timeout``
-        argument can be a nonnegative float expressing seconds, or ``None``.  If
-        a float is given, subsequent channel read/write operations will raise
-        a timeout exception if the timeout period value has elapsed before the
-        operation has completed.  Setting a timeout of ``None`` disables
-        timeouts on socket operations.
+        argument can be a nonnegative float expressing seconds, or ``None``.
+        If a float is given, subsequent channel read/write operations will
+        raise a timeout exception if the timeout period value has elapsed
+        before the operation has completed.  Setting a timeout of ``None``
+        disables timeouts on socket operations.
 
         ``chan.settimeout(0.0)`` is equivalent to ``chan.setblocking(0)``;
         ``chan.settimeout(None)`` is equivalent to ``chan.setblocking(1)``.
@@ -583,11 +686,11 @@ class Channel (ClosingContextManager):
         """
         Receive data from the channel.  The return value is a string
         representing the data received.  The maximum amount of data to be
-        received at once is specified by ``nbytes``.  If a string of length zero
-        is returned, the channel stream has closed.
+        received at once is specified by ``nbytes``.  If a string of
+        length zero is returned, the channel stream has closed.
 
         :param int nbytes: maximum number of bytes to read.
-        :return: received data, as a `str`
+        :return: received data, as a ``str``/``bytes``.
 
         :raises socket.timeout:
             if no data is ready before the timeout set by `settimeout`.
@@ -721,7 +824,6 @@ class Channel (ClosingContextManager):
         m.add_int(1)
         return self._send(s, m)
 
-
     def sendall(self, s):
         """
         Send data to the channel, without allowing partial results.  Unlike
@@ -734,7 +836,7 @@ class Channel (ClosingContextManager):
             if sending stalled for longer than the timeout set by `settimeout`.
         :raises socket.error:
             if an error occurred before the entire string was sent.
-        
+
         .. note::
             If the channel is closed while only part of the data has been
             sent, there is no way to determine how much data (if any) was sent.
@@ -758,7 +860,7 @@ class Channel (ClosingContextManager):
             if sending stalled for longer than the timeout set by `settimeout`.
         :raises socket.error:
             if an error occurred before the entire string was sent.
-            
+
         .. versionadded:: 1.1
         """
         while s:
@@ -787,12 +889,30 @@ class Channel (ClosingContextManager):
         client, it only makes sense to open this file for reading.  For a
         server, it only makes sense to open this file for writing.
 
-        :return: `.ChannelFile` object which can be used for Python file I/O.
+        :returns:
+            `.ChannelStderrFile` object which can be used for Python file I/O.
 
         .. versionadded:: 1.1
         """
         return ChannelStderrFile(*([self] + list(params)))
 
+    def makefile_stdin(self, *params):
+        """
+        Return a file-like object associated with this channel's stdin
+        stream.
+
+        The optional ``mode`` and ``bufsize`` arguments are interpreted the
+        same way as by the built-in ``file()`` function in Python.  For a
+        client, it only makes sense to open this file for writing.  For a
+        server, it only makes sense to open this file for reading.
+
+        :returns:
+            `.ChannelStdinFile` object which can be used for Python file I/O.
+
+        .. versionadded:: 2.6
+        """
+        return ChannelStdinFile(*([self] + list(params)))
+
     def fileno(self):
         """
         Returns an OS-level file descriptor which can be used for polling, but
@@ -870,7 +990,13 @@ class Channel (ClosingContextManager):
         """
         self.shutdown(1)
 
-    ###  calls from Transport
+    @property
+    def _closed(self):
+        # Concession to Python 3's socket API, which has a private ._closed
+        # attribute instead of a semipublic .closed attribute.
+        return self.closed
+
+    # ...calls from Transport
 
     def _set_transport(self, transport):
         self.transport = transport
@@ -879,21 +1005,25 @@ class Channel (ClosingContextManager):
     def _set_window(self, window_size, max_packet_size):
         self.in_window_size = window_size
         self.in_max_packet_size = max_packet_size
-        # threshold of bytes we receive before we bother to send a window update
+        # threshold of bytes we receive before we bother to send
+        # a window update
         self.in_window_threshold = window_size // 10
         self.in_window_sofar = 0
-        self._log(DEBUG, 'Max packet in: %d bytes' % max_packet_size)
+        self._log(DEBUG, "Max packet in: {} bytes".format(max_packet_size))
 
     def _set_remote_channel(self, chanid, window_size, max_packet_size):
         self.remote_chanid = chanid
         self.out_window_size = window_size
-        self.out_max_packet_size = self.transport. \
-            _sanitize_packet_size(max_packet_size)
+        self.out_max_packet_size = self.transport._sanitize_packet_size(
+            max_packet_size
+        )
         self.active = 1
-        self._log(DEBUG, 'Max packet out: %d bytes' % self.out_max_packet_size)
+        self._log(
+            DEBUG, "Max packet out: {} bytes".format(self.out_max_packet_size)
+        )
 
     def _request_success(self, m):
-        self._log(DEBUG, 'Sesch channel %d request ok' % self.chanid)
+        self._log(DEBUG, "Sesch channel {} request ok".format(self.chanid))
         self.event_ready = True
         self.event.set()
         return
@@ -920,7 +1050,9 @@ class Channel (ClosingContextManager):
         code = m.get_int()
         s = m.get_binary()
         if code != 1:
-            self._log(ERROR, 'unknown extended_data type %d; discarding' % code)
+            self._log(
+                ERROR, "unknown extended_data type {}; discarding".format(code)
+            )
             return
         if self.combine_stderr:
             self._feed(s)
@@ -932,7 +1064,7 @@ class Channel (ClosingContextManager):
         self.lock.acquire()
         try:
             if self.ultra_debug:
-                self._log(DEBUG, 'window up %d' % nbytes)
+                self._log(DEBUG, "window up {}".format(nbytes))
             self.out_window_size += nbytes
             self.out_buffer_cv.notifyAll()
         finally:
@@ -943,14 +1075,14 @@ class Channel (ClosingContextManager):
         want_reply = m.get_boolean()
         server = self.transport.server_object
         ok = False
-        if key == 'exit-status':
+        if key == "exit-status":
             self.exit_status = m.get_int()
             self.status_event.set()
             ok = True
-        elif key == 'xon-xoff':
+        elif key == "xon-xoff":
             # ignore
             ok = True
-        elif key == 'pty-req':
+        elif key == "pty-req":
             term = m.get_string()
             width = m.get_int()
             height = m.get_int()
@@ -960,33 +1092,34 @@ class Channel (ClosingContextManager):
             if server is None:
                 ok = False
             else:
-                ok = server.check_channel_pty_request(self, term, width, height, pixelwidth,
-                                                      pixelheight, modes)
-        elif key == 'shell':
+                ok = server.check_channel_pty_request(
+                    self, term, width, height, pixelwidth, pixelheight, modes
+                )
+        elif key == "shell":
             if server is None:
                 ok = False
             else:
                 ok = server.check_channel_shell_request(self)
-        elif key == 'env':
+        elif key == "env":
             name = m.get_string()
             value = m.get_string()
             if server is None:
                 ok = False
             else:
                 ok = server.check_channel_env_request(self, name, value)
-        elif key == 'exec':
-            cmd = m.get_text()
+        elif key == "exec":
+            cmd = m.get_string()
             if server is None:
                 ok = False
             else:
                 ok = server.check_channel_exec_request(self, cmd)
-        elif key == 'subsystem':
+        elif key == "subsystem":
             name = m.get_text()
             if server is None:
                 ok = False
             else:
                 ok = server.check_channel_subsystem_request(self, name)
-        elif key == 'window-change':
+        elif key == "window-change":
             width = m.get_int()
             height = m.get_int()
             pixelwidth = m.get_int()
@@ -994,9 +1127,10 @@ class Channel (ClosingContextManager):
             if server is None:
                 ok = False
             else:
-                ok = server.check_channel_window_change_request(self, width, height, pixelwidth,
-                                                                pixelheight)
-        elif key == 'x11-req':
+                ok = server.check_channel_window_change_request(
+                    self, width, height, pixelwidth, pixelheight
+                )
+        elif key == "x11-req":
             single_connection = m.get_boolean()
             auth_proto = m.get_text()
             auth_cookie = m.get_binary()
@@ -1004,15 +1138,20 @@ class Channel (ClosingContextManager):
             if server is None:
                 ok = False
             else:
-                ok = server.check_channel_x11_request(self, single_connection,
-                                                      auth_proto, auth_cookie, screen_number)
-        elif key == 'auth-agent-req@openssh.com':
+                ok = server.check_channel_x11_request(
+                    self,
+                    single_connection,
+                    auth_proto,
+                    auth_cookie,
+                    screen_number,
+                )
+        elif key == "auth-agent-req@openssh.com":
             if server is None:
                 ok = False
             else:
                 ok = server.check_channel_forward_agent_request(self)
         else:
-            self._log(DEBUG, 'Unhandled channel request "%s"' % key)
+            self._log(DEBUG, 'Unhandled channel request "{}"'.format(key))
             ok = False
         if want_reply:
             m = Message()
@@ -1034,7 +1173,7 @@ class Channel (ClosingContextManager):
                     self._pipe.set_forever()
         finally:
             self.lock.release()
-        self._log(DEBUG, 'EOF received (%s)', self._name)
+        self._log(DEBUG, "EOF received ({})".format(self._name))
 
     def _handle_close(self, m):
         self.lock.acquire()
@@ -1047,15 +1186,16 @@ class Channel (ClosingContextManager):
             if m is not None:
                 self.transport._send_user_message(m)
 
-    ###  internals...
+    # ...internals...
 
     def _send(self, s, m):
         size = len(s)
         self.lock.acquire()
         try:
             if self.closed:
-                # this doesn't seem useful, but it is the documented behavior of Socket
-                raise socket.error('Socket is closed')
+                # this doesn't seem useful, but it is the documented behavior
+                # of Socket
+                raise socket.error("Socket is closed")
             size = self._wait_for_send_window(size)
             if size == 0:
                 # eof or similar
@@ -1082,7 +1222,7 @@ class Channel (ClosingContextManager):
             return
         e = self.transport.get_exception()
         if e is None:
-            e = SSHException('Channel closed.')
+            e = SSHException("Channel closed.")
         raise e
 
     def _set_closed(self):
@@ -1105,7 +1245,7 @@ class Channel (ClosingContextManager):
         m.add_byte(cMSG_CHANNEL_EOF)
         m.add_int(self.remote_chanid)
         self.eof_sent = True
-        self._log(DEBUG, 'EOF sent (%s)', self._name)
+        self._log(DEBUG, "EOF sent ({})".format(self._name))
         return m
 
     def _close_internal(self):
@@ -1122,7 +1262,8 @@ class Channel (ClosingContextManager):
         return m1, m2
 
     def _unlink(self):
-        # server connection could die before we become active: still signal the close!
+        # server connection could die before we become active:
+        # still signal the close!
         if self.closed:
             return
         self.lock.acquire()
@@ -1138,12 +1279,14 @@ class Channel (ClosingContextManager):
             if self.closed or self.eof_received or not self.active:
                 return 0
             if self.ultra_debug:
-                self._log(DEBUG, 'addwindow %d' % n)
+                self._log(DEBUG, "addwindow {}".format(n))
             self.in_window_sofar += n
             if self.in_window_sofar <= self.in_window_threshold:
                 return 0
             if self.ultra_debug:
-                self._log(DEBUG, 'addwindow send %d' % self.in_window_sofar)
+                self._log(
+                    DEBUG, "addwindow send {}".format(self.in_window_sofar)
+                )
             out = self.in_window_sofar
             self.in_window_sofar = 0
             return out
@@ -1165,7 +1308,8 @@ class Channel (ClosingContextManager):
             # should we block?
             if self.timeout == 0.0:
                 raise socket.timeout()
-            # loop here in case we get woken up but a different thread has filled the buffer
+            # loop here in case we get woken up but a different thread has
+            # filled the buffer
             timeout = self.timeout
             while self.out_window_size == 0:
                 if self.closed or self.eof_sent:
@@ -1185,11 +1329,11 @@ class Channel (ClosingContextManager):
             size = self.out_max_packet_size - 64
         self.out_window_size -= size
         if self.ultra_debug:
-            self._log(DEBUG, 'window down to %d' % self.out_window_size)
+            self._log(DEBUG, "window down to {}".format(self.out_window_size))
         return size
 
 
-class ChannelFile (BufferedFile):
+class ChannelFile(BufferedFile):
     """
     A file-like wrapper around `.Channel`.  A ChannelFile is created by calling
     `Channel.makefile`.
@@ -1202,7 +1346,7 @@ class ChannelFile (BufferedFile):
         flush the buffer.
     """
 
-    def __init__(self, channel, mode='r', bufsize=-1):
+    def __init__(self, channel, mode="r", bufsize=-1):
         self.channel = channel
         BufferedFile.__init__(self)
         self._set_mode(mode, bufsize)
@@ -1211,7 +1355,7 @@ class ChannelFile (BufferedFile):
         """
         Returns a string representation of this object, for debugging.
         """
-        return '<paramiko.ChannelFile from ' + repr(self.channel) + '>'
+        return "<paramiko.ChannelFile from " + repr(self.channel) + ">"
 
     def _read(self, size):
         return self.channel.recv(size)
@@ -1221,9 +1365,12 @@ class ChannelFile (BufferedFile):
         return len(data)
 
 
-class ChannelStderrFile (ChannelFile):
-    def __init__(self, channel, mode='r', bufsize=-1):
-        ChannelFile.__init__(self, channel, mode, bufsize)
+class ChannelStderrFile(ChannelFile):
+    """
+    A file-like wrapper around `.Channel` stderr.
+
+    See `Channel.makefile_stderr` for details.
+    """
 
     def _read(self, size):
         return self.channel.recv_stderr(size)
@@ -1233,4 +1380,13 @@ class ChannelStderrFile (ChannelFile):
         return len(data)
 
 
-# vim: set shiftwidth=4 expandtab :
+class ChannelStdinFile(ChannelFile):
+    """
+    A file-like wrapper around `.Channel` stdin.
+
+    See `Channel.makefile_stdin` for details.
+    """
+
+    def close(self):
+        super(ChannelStdinFile, self).close()
+        self.channel.shutdown_write()
